summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/statistics/statisticscontact.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-15 15:49:40 -0600
committerTimothy Pearson <[email protected]>2011-12-15 15:49:40 -0600
commit808e453c56036211f57482ed847d54aca01bba68 (patch)
tree75515d5768dea10d4fbe4cd772e0a89c1c4b3aa9 /kopete/plugins/statistics/statisticscontact.h
parentcd9b9ed7fd0ac8a75106148254aa58e2e5c04863 (diff)
downloadtdenetwork-808e453c56036211f57482ed847d54aca01bba68.tar.gz
tdenetwork-808e453c56036211f57482ed847d54aca01bba68.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kopete/plugins/statistics/statisticscontact.h')
-rw-r--r--kopete/plugins/statistics/statisticscontact.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/plugins/statistics/statisticscontact.h b/kopete/plugins/statistics/statisticscontact.h
index 1559e1fd..9d7f6575 100644
--- a/kopete/plugins/statistics/statisticscontact.h
+++ b/kopete/plugins/statistics/statisticscontact.h
@@ -55,9 +55,9 @@ public:
TQString statisticsContactId() { return m_statisticsContactId; }
/** \brief Access method
- * \return m_oldtqStatus
+ * \return m_oldStatus
*/
- Kopete::OnlineStatus::StatusType oldtqStatus() { return m_oldtqStatus; }
+ Kopete::OnlineStatus::StatusType oldStatus() { return m_oldStatus; }
/** \brief Access method
* \return m_oldStatusDateTime
@@ -106,7 +106,7 @@ public:
/**
* \returns true if contact was status at dt, false else.
*/
- bool wastqStatus(TQDateTime dt, Kopete::OnlineStatus::StatusType status);
+ bool wasStatus(TQDateTime dt, Kopete::OnlineStatus::StatusType status);
/**
* \returns the status of the contact at dt. Return false if dt is invalid.
@@ -209,9 +209,9 @@ private:
/**
* The interest of statistics contact is to manage the changes of status
* in order to correctly update the database. That's why here we keep the oldtqStatus
*/
- Kopete::OnlineStatus::StatusType m_oldtqStatus;
+ Kopete::OnlineStatus::StatusType m_oldStatus;
/// We keep the old status datetime here
TQDateTime m_oldStatusDateTime;
@@ -209,9 +209,9 @@ private:
/**
* The interest of statistics contact is to manage the changes of status
- * in order to correctly update the database. That's why here we keep the oldtqStatus
+ * in order to correctly update the database. That's why here we keep the oldStatus
*/